// Package  implements the Azure ARM  service API version 1.5.
//
// ## Welcome to Enigma Vault's API Documentation
//
// Enigma Vault encrypts and tokenizes data of all shapes and sizes. Enigma Vault provides the following services:
//
// - **Card Vault**: encrypts and tokenizes card data. One way in and no way out except through our proxy services.
// - **Data Vault**: encrypts and tokenizes data. Encrypted data can be easily searched and retrieved.
// - **File Vault**: encrypts and stores files up to 5 GB in size.
//
// To get started, head on over to our [AWS Marketplace
// page](https://aws.amazon.com/marketplace/seller-profile?id=c77b8db1-5511-48b7-8ce5-9a8d4a1a8018) and select one of
// our offerings. Once you have credentials, feel free to use the [PostMan app](https://www.postman.com/downloads/)
// or our [Swagger UI](https://api.enigmavault.io/index.html).
//
// Enigma Vault utilizes AWS Lambda for performance and security reasons. Are you using Lambda as well? You can
// integrate using your favorite runtime http client or you can also use one of the SDKs below.
//
// ## Version 1.5 Notes
// ### 02/06/2022
// - Card Vault: you can now generate Luhn passable tokens that preserve the first six and last four of the card
// number. Because the tokens look like card numbers, the token has been moved to the header.
// ## SDKs
//
// - [C#](https://www.enigmavault.io/sdks/1.5/enigma-vault-csharp-sdk-1.5.zip)
// - [Java](https://www.enigmavault.io/sdks/1.5/enigma-vault-java-sdk-1.5.zip)
// - [Python](https://www.enigmavault.io/sdks/1.5/enigma-vault-python-sdk-1.5.zip)
// - [Node.js](https://www.enigmavault.io/sdks/1.5/enigma-vault-nodejs-sdk-1.5.zip)
// - [Go](https://www.enigmavault.io/sdks/1.5/enigma-vault-go-sdk-1.5.zip)
package

// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

import (
    "context"
    "github.com/Azure/go-autorest/autorest"
    "github.com/Azure/go-autorest/autorest/azure"
    "github.com/Azure/go-autorest/autorest/validation"
    "github.com/Azure/go-autorest/tracing"
    "github.com/gofrs/uuid"
    "net/http"
)

const (
// DefaultBaseURI is the default URI used for the service
DefaultBaseURI = "")

// BaseClient is the base client for .
type BaseClient struct {
    autorest.Client
    BaseURI string
}

// New creates an instance of the BaseClient client.
func New()BaseClient {
    return NewWithBaseURI(DefaultBaseURI, )
}

// NewWithBaseURI creates an instance of the BaseClient client using a custom endpoint.  Use this when interacting with
// an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
func NewWithBaseURI(baseURI string, ) BaseClient {
    return BaseClient{
        Client: autorest.NewClientWithUserAgent(UserAgent()),
        BaseURI: baseURI,
    }
}

    // CardProxyMethod this endpoint allows you to use a stored card without touching the card data. Build out the request
    // meant for the upstream url and then use the following placeholders to have the endpoint populate them with card
    // data: ${ccn}, ${cvv}, ${fullName}, ${lastName}, ${firstName}, ${cardType}, ${mm}, ${yy}, and ${yyyy}. Supports
    // GET/PUT/POST/DELETE.
        // Parameters:
            // body - token and gateway information.
            // cardToken - card token.
            // xAPIVersion - the requested API version
            // ephemeralKey - expiring key for temporary access.
    func (client BaseClient) CardProxyMethod(ctx context.Context, body CardProxyModelType, cardToken string, xAPIVersion string, ephemeralKey *uuid.UUID) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.CardProxyMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: body,
             Constraints: []validation.Constraint{	{Target: "body.URL", Name: validation.Null, Rule: true, Chain: nil },
            	{Target: "body.HTTPMethod", Name: validation.Null, Rule: true, Chain: nil }}},
            { TargetValue: cardToken,
             Constraints: []validation.Constraint{	{Target: "cardToken", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "cardToken", Name: validation.MinLength, Rule: 13, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "CardProxyMethod", err.Error())
            }

            req, err := client.CardProxyMethodPreparer(ctx, body, cardToken, xAPIVersion, ephemeralKey)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "CardProxyMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.CardProxyMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "CardProxyMethod", resp, "Failure sending request")
            return
            }

            result, err = client.CardProxyMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "CardProxyMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // CardProxyMethodPreparer prepares the CardProxyMethod request.
        func (client BaseClient) CardProxyMethodPreparer(ctx context.Context, body CardProxyModelType, cardToken string, xAPIVersion string, ephemeralKey *uuid.UUID) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        }
            if ephemeralKey != nil {
            queryParameters["ephemeralKey"] = autorest.Encode("query",*ephemeralKey)
            }

        preparer := autorest.CreatePreparer(
    autorest.AsContentType("application/json; charset=utf-8"),
    autorest.AsPost(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/proxy"),
    autorest.WithJSON(body),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("cardToken", autorest.String(cardToken)),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // CardProxyMethodSender sends the CardProxyMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) CardProxyMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // CardProxyMethodResponder handles the response to the CardProxyMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) CardProxyMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError,http.StatusServiceUnavailable),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // DeleteCardMethod returns an empty 204 response on success.
        // Parameters:
            // cardToken - card token.
            // xAPIVersion - the requested API version
    func (client BaseClient) DeleteCardMethod(ctx context.Context, cardToken string, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.DeleteCardMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: cardToken,
             Constraints: []validation.Constraint{	{Target: "cardToken", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "cardToken", Name: validation.MinLength, Rule: 13, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "DeleteCardMethod", err.Error())
            }

            req, err := client.DeleteCardMethodPreparer(ctx, cardToken, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "DeleteCardMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.DeleteCardMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "DeleteCardMethod", resp, "Failure sending request")
            return
            }

            result, err = client.DeleteCardMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "DeleteCardMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // DeleteCardMethodPreparer prepares the DeleteCardMethod request.
        func (client BaseClient) DeleteCardMethodPreparer(ctx context.Context, cardToken string, xAPIVersion string) (*http.Request, error) {
        preparer := autorest.CreatePreparer(
    autorest.AsDelete(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/cards"),
    autorest.WithHeader("cardToken", autorest.String(cardToken)),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // DeleteCardMethodSender sends the DeleteCardMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) DeleteCardMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // DeleteCardMethodResponder handles the response to the DeleteCardMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) DeleteCardMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusNoContent,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // DeleteDataSecretMethod sends the delete data secret request.
        // Parameters:
            // tokenParameter - reference to the vaulted secret.
            // xAPIVersion - the requested API version
    func (client BaseClient) DeleteDataSecretMethod(ctx context.Context, tokenParameter string, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.DeleteDataSecretMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: tokenParameter,
             Constraints: []validation.Constraint{	{Target: "tokenParameter", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "tokenParameter", Name: validation.MinLength, Rule: 72, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "DeleteDataSecretMethod", err.Error())
            }

            req, err := client.DeleteDataSecretMethodPreparer(ctx, tokenParameter, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "DeleteDataSecretMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.DeleteDataSecretMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "DeleteDataSecretMethod", resp, "Failure sending request")
            return
            }

            result, err = client.DeleteDataSecretMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "DeleteDataSecretMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // DeleteDataSecretMethodPreparer prepares the DeleteDataSecretMethod request.
        func (client BaseClient) DeleteDataSecretMethodPreparer(ctx context.Context, tokenParameter string, xAPIVersion string) (*http.Request, error) {
            pathParameters := map[string]interface{} {
            "token": autorest.Encode("path",tokenParameter),
            }

        preparer := autorest.CreatePreparer(
    autorest.AsDelete(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPathParameters("/datavault/secrets/{token}",pathParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // DeleteDataSecretMethodSender sends the DeleteDataSecretMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) DeleteDataSecretMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // DeleteDataSecretMethodResponder handles the response to the DeleteDataSecretMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) DeleteDataSecretMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusNoContent,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // DeleteFileMethod on successful deletion, a 204 response is returned.
        // Parameters:
            // fileName - tokenized file name.
            // xAPIVersion - the requested API version
    func (client BaseClient) DeleteFileMethod(ctx context.Context, fileName string, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.DeleteFileMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: fileName,
             Constraints: []validation.Constraint{	{Target: "fileName", Name: validation.Pattern, Rule: `^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$`, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "DeleteFileMethod", err.Error())
            }

            req, err := client.DeleteFileMethodPreparer(ctx, fileName, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "DeleteFileMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.DeleteFileMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "DeleteFileMethod", resp, "Failure sending request")
            return
            }

            result, err = client.DeleteFileMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "DeleteFileMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // DeleteFileMethodPreparer prepares the DeleteFileMethod request.
        func (client BaseClient) DeleteFileMethodPreparer(ctx context.Context, fileName string, xAPIVersion string) (*http.Request, error) {
            pathParameters := map[string]interface{} {
            "fileName": autorest.Encode("path",fileName),
            }

        preparer := autorest.CreatePreparer(
    autorest.AsDelete(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPathParameters("/filevault/files/{fileName}",pathParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // DeleteFileMethodSender sends the DeleteFileMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) DeleteFileMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // DeleteFileMethodResponder handles the response to the DeleteFileMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) DeleteFileMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusNoContent,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetCardEphemeralKeyMethod the ephemeralKey is a one time use expiring key that allows an external client to use a
    // card token. The destinationClientId is a valid Enigma Vault clientId of the destination app. The time to live (ttl)
    // is in seconds.
        // Parameters:
            // cardToken - reference to the vaulted card.
            // destinationClientID - enigma Vault client granted use of the ephemeralKey.
            // xAPIVersion - the requested API version
            // TTL - time to live in seconds, max of 1800 seconds. This is only applicable when
            // the card has a ttl of 0 (permanent). Otherwise the ephemeralKey ttl is set to the card ttl.
    func (client BaseClient) GetCardEphemeralKeyMethod(ctx context.Context, cardToken string, destinationClientID string, xAPIVersion string, TTL *int32) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetCardEphemeralKeyMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: cardToken,
             Constraints: []validation.Constraint{	{Target: "cardToken", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "cardToken", Name: validation.MinLength, Rule: 13, Chain: nil }}},
            { TargetValue: TTL,
             Constraints: []validation.Constraint{	{Target: "TTL", Name: validation.Null, Rule: false ,
            Chain: []validation.Constraint{	{Target: "TTL", Name: validation.InclusiveMaximum, Rule: int64(1800), Chain: nil },
            	{Target: "TTL", Name: validation.InclusiveMinimum, Rule: int64(60), Chain: nil },
            }}}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetCardEphemeralKeyMethod", err.Error())
            }

            req, err := client.GetCardEphemeralKeyMethodPreparer(ctx, cardToken, destinationClientID, xAPIVersion, TTL)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardEphemeralKeyMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetCardEphemeralKeyMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardEphemeralKeyMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetCardEphemeralKeyMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardEphemeralKeyMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetCardEphemeralKeyMethodPreparer prepares the GetCardEphemeralKeyMethod request.
        func (client BaseClient) GetCardEphemeralKeyMethodPreparer(ctx context.Context, cardToken string, destinationClientID string, xAPIVersion string, TTL *int32) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        "destinationClientId": autorest.Encode("query",destinationClientID),
        }
            if TTL != nil {
            queryParameters["ttl"] = autorest.Encode("query",*TTL)
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/cards/ephemeralkeys"),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("cardToken", autorest.String(cardToken)),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetCardEphemeralKeyMethodSender sends the GetCardEphemeralKeyMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetCardEphemeralKeyMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetCardEphemeralKeyMethodResponder handles the response to the GetCardEphemeralKeyMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetCardEphemeralKeyMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetCardProcessFormMethod the card processing UI allows your customers to enter their card data and process upstream
    // with the payment gateway without your app touching it. Build out the request meant for the upstream url and then use
    // the following placeholders to have the endpoint populate them with card data: ${total}, ${ccn}, ${cvv}, ${fullName},
    // ${lastName}, ${firstName}, ${cardType}, ${mm}, ${yy}, and ${yyyy}. Supports GET/PUT/POST/DELETE. The customer is
    // redirected back to your app (callback url) via POST with the parameter eVsessionId. You can then use
    // /cardvault/process/sessions/ to determine the adjudication. The session information is available for 72 hours. If
    // the customer choses to save their card, it will be available through the sessions endpoint. If the customer chooses
    // to cancel or if the form timeouts, evException will have a value within the POST callback. For cancels,
    // evException's value will be 'cancel'. For timeouts, the evException's value will be 'timeout'. There are multiple
    // ways to integrate the card process form. You can use it within a popup, redirect or simple iframe.
        // Parameters:
            // body - gateway and cart information.
            // callbackURL - URL the user is redirected to after storing the card.
            // showTimer - show or hide the timer.
            // showCard - show or hide the card visual.
            // TTL - form session time to live in seconds. After it expires, the form can no
            // longer be used.
            // xAPIVersion - the requested API version
            // preserveFormat - if true, a Luhn passable token is returned consisting of the original first six and last
            // four.
            // cardTypes - card types, comma delimited. Omit for any card.
            // (amex, diners_club_carte_blanche, diners_club_international,
            // jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro, uatp, mir).
            // pageHeader - configurable page header.
            // submitButtonText - text of the submit button.
            // language - the language to use on the form. Currently en (English), es (Spanish),
            // fr (French), and zh-Hans (Chinese simplified) are available.
            // submitButtonColor - the hex color of the submit button.
            // cancelButtonColor - the hex color of the cancel button.
            // pageColor - the hex color of the page background.
            // submitButtonTextColor - the hex color of the submit button text.
            // cancelButtonTextColor - the hex color of the cancel button text.
            // pageTextColor - the hex color of the page text.
            // cartTableBorderColor - the hex color of the cart table header and border.
            // cartTableAlternateRowColor - the hex color of the cart table's alternating rows.
    func (client BaseClient) GetCardProcessFormMethod(ctx context.Context, body CardProcessModelType, callbackURL string, showTimer bool, showCard bool, TTL int32, xAPIVersion string, preserveFormat *bool, cardTypes string, pageHeader string, submitButtonText string, language string, submitButtonColor string, cancelButtonColor string, pageColor string, submitButtonTextColor string, cancelButtonTextColor string, pageTextColor string, cartTableBorderColor string, cartTableAlternateRowColor string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetCardProcessFormMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: body,
             Constraints: []validation.Constraint{	{Target: "body.GatewayRequest", Name: validation.Null, Rule: true ,
            Chain: []validation.Constraint{	{Target: "body.GatewayRequest.URL", Name: validation.Null, Rule: true, Chain: nil },
            	{Target: "body.GatewayRequest.HTTPMethod", Name: validation.Null, Rule: true, Chain: nil },
            }},
            	{Target: "body.Cart", Name: validation.Null, Rule: true ,
            Chain: []validation.Constraint{	{Target: "body.Cart.CultureCode", Name: validation.Null, Rule: true, Chain: nil },
            	{Target: "body.Cart.CartItems", Name: validation.Null, Rule: true, Chain: nil },
            	{Target: "body.Cart.Total", Name: validation.Null, Rule: true, Chain: nil },
            	{Target: "body.Cart.GatewayIntegersOnly", Name: validation.Null, Rule: true, Chain: nil },
            }}}},
            { TargetValue: TTL,
             Constraints: []validation.Constraint{	{Target: "TTL", Name: validation.InclusiveMaximum, Rule: int64(1800), Chain: nil },
            	{Target: "TTL", Name: validation.InclusiveMinimum, Rule: int64(60), Chain: nil }}},
            { TargetValue: pageHeader,
             Constraints: []validation.Constraint{	{Target: "pageHeader", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "pageHeader", Name: validation.MaxLength, Rule: 35, Chain: nil },
            	{Target: "pageHeader", Name: validation.MinLength, Rule: 3, Chain: nil },
            }}}},
            { TargetValue: submitButtonText,
             Constraints: []validation.Constraint{	{Target: "submitButtonText", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "submitButtonText", Name: validation.MaxLength, Rule: 20, Chain: nil },
            	{Target: "submitButtonText", Name: validation.MinLength, Rule: 0, Chain: nil },
            }}}},
            { TargetValue: language,
             Constraints: []validation.Constraint{	{Target: "language", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "language", Name: validation.Pattern, Rule: `^en|es|fr|zh-Hans$`, Chain: nil },
            }}}},
            { TargetValue: submitButtonColor,
             Constraints: []validation.Constraint{	{Target: "submitButtonColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "submitButtonColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: cancelButtonColor,
             Constraints: []validation.Constraint{	{Target: "cancelButtonColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "cancelButtonColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: pageColor,
             Constraints: []validation.Constraint{	{Target: "pageColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "pageColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: submitButtonTextColor,
             Constraints: []validation.Constraint{	{Target: "submitButtonTextColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "submitButtonTextColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: cancelButtonTextColor,
             Constraints: []validation.Constraint{	{Target: "cancelButtonTextColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "cancelButtonTextColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: pageTextColor,
             Constraints: []validation.Constraint{	{Target: "pageTextColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "pageTextColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: cartTableBorderColor,
             Constraints: []validation.Constraint{	{Target: "cartTableBorderColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "cartTableBorderColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: cartTableAlternateRowColor,
             Constraints: []validation.Constraint{	{Target: "cartTableAlternateRowColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "cartTableAlternateRowColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetCardProcessFormMethod", err.Error())
            }

            req, err := client.GetCardProcessFormMethodPreparer(ctx, body, callbackURL, showTimer, showCard, TTL, xAPIVersion, preserveFormat, cardTypes, pageHeader, submitButtonText, language, submitButtonColor, cancelButtonColor, pageColor, submitButtonTextColor, cancelButtonTextColor, pageTextColor, cartTableBorderColor, cartTableAlternateRowColor)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardProcessFormMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetCardProcessFormMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardProcessFormMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetCardProcessFormMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardProcessFormMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetCardProcessFormMethodPreparer prepares the GetCardProcessFormMethod request.
        func (client BaseClient) GetCardProcessFormMethodPreparer(ctx context.Context, body CardProcessModelType, callbackURL string, showTimer bool, showCard bool, TTL int32, xAPIVersion string, preserveFormat *bool, cardTypes string, pageHeader string, submitButtonText string, language string, submitButtonColor string, cancelButtonColor string, pageColor string, submitButtonTextColor string, cancelButtonTextColor string, pageTextColor string, cartTableBorderColor string, cartTableAlternateRowColor string) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        "callbackUrl": autorest.Encode("query",callbackURL),
        "showCard": autorest.Encode("query",showCard),
        "showTimer": autorest.Encode("query",showTimer),
        "ttl": autorest.Encode("query",TTL),
        }
            if preserveFormat != nil {
            queryParameters["preserveFormat"] = autorest.Encode("query",*preserveFormat)
            }
            if len(cardTypes) > 0 {
            queryParameters["cardTypes"] = autorest.Encode("query",cardTypes)
            }
            if len(pageHeader) > 0 {
            queryParameters["pageHeader"] = autorest.Encode("query",pageHeader)
            }
            if len(submitButtonText) > 0 {
            queryParameters["submitButtonText"] = autorest.Encode("query",submitButtonText)
                } else {
                queryParameters["submitButtonText"] = autorest.Encode("query","Pay Now")
            }
            if len(language) > 0 {
            queryParameters["language"] = autorest.Encode("query",language)
                } else {
                queryParameters["language"] = autorest.Encode("query","en")
            }
            if len(submitButtonColor) > 0 {
            queryParameters["submitButtonColor"] = autorest.Encode("query",submitButtonColor)
                } else {
                queryParameters["submitButtonColor"] = autorest.Encode("query","#0078e7")
            }
            if len(cancelButtonColor) > 0 {
            queryParameters["cancelButtonColor"] = autorest.Encode("query",cancelButtonColor)
                } else {
                queryParameters["cancelButtonColor"] = autorest.Encode("query","#f08080")
            }
            if len(pageColor) > 0 {
            queryParameters["pageColor"] = autorest.Encode("query",pageColor)
                } else {
                queryParameters["pageColor"] = autorest.Encode("query","#ffffff")
            }
            if len(submitButtonTextColor) > 0 {
            queryParameters["submitButtonTextColor"] = autorest.Encode("query",submitButtonTextColor)
                } else {
                queryParameters["submitButtonTextColor"] = autorest.Encode("query","#ffffff")
            }
            if len(cancelButtonTextColor) > 0 {
            queryParameters["cancelButtonTextColor"] = autorest.Encode("query",cancelButtonTextColor)
                } else {
                queryParameters["cancelButtonTextColor"] = autorest.Encode("query","#000000")
            }
            if len(pageTextColor) > 0 {
            queryParameters["pageTextColor"] = autorest.Encode("query",pageTextColor)
                } else {
                queryParameters["pageTextColor"] = autorest.Encode("query","#000000")
            }
            if len(cartTableBorderColor) > 0 {
            queryParameters["cartTableBorderColor"] = autorest.Encode("query",cartTableBorderColor)
                } else {
                queryParameters["cartTableBorderColor"] = autorest.Encode("query","#e0e0e0")
            }
            if len(cartTableAlternateRowColor) > 0 {
            queryParameters["cartTableAlternateRowColor"] = autorest.Encode("query",cartTableAlternateRowColor)
                } else {
                queryParameters["cartTableAlternateRowColor"] = autorest.Encode("query","#f2f2f2")
            }

        preparer := autorest.CreatePreparer(
    autorest.AsContentType("application/json; charset=utf-8"),
    autorest.AsPost(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/process/forms"),
    autorest.WithJSON(body),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetCardProcessFormMethodSender sends the GetCardProcessFormMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetCardProcessFormMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetCardProcessFormMethodResponder handles the response to the GetCardProcessFormMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetCardProcessFormMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetCardProcessSessionMethod obtain the results from the gateway and retrieve the card token if the customer decided
    // to save it.
        // Parameters:
            // ID - session ID
            // xAPIVersion - the requested API version
    func (client BaseClient) GetCardProcessSessionMethod(ctx context.Context, ID uuid.UUID, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetCardProcessSessionMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
        req, err := client.GetCardProcessSessionMethodPreparer(ctx, ID, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardProcessSessionMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetCardProcessSessionMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardProcessSessionMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetCardProcessSessionMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardProcessSessionMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetCardProcessSessionMethodPreparer prepares the GetCardProcessSessionMethod request.
        func (client BaseClient) GetCardProcessSessionMethodPreparer(ctx context.Context, ID uuid.UUID, xAPIVersion string) (*http.Request, error) {
            pathParameters := map[string]interface{} {
            "id": autorest.Encode("path",ID),
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPathParameters("/cardvault/process/sessions/{id}",pathParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetCardProcessSessionMethodSender sends the GetCardProcessSessionMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetCardProcessSessionMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetCardProcessSessionMethodResponder handles the response to the GetCardProcessSessionMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetCardProcessSessionMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetCardStoreFormMethod the card store form allows your app to store and later use customer card data without
    // touching it. After the cardTtl expires, the card is deleted. If the user decides to save the card, the card is
    // stored permanently. If you're seeking to permanently store the card outside of a transaction (wallet style), set
    // walletSave to true. If you set walletSave to true, the buttonText and cardTtl are overriden. If walletSave is true
    // the CVV isn't requested. If you intend to use the card in a transaction within 30 minutes, set walletSave to false.
    // On callback, your app will receive via POST the card token within the parameter eVtoken. If the customer chooses to
    // cancel or if the form timeouts, the evException parameter will contain the reason. For cancels, evException's value
    // will be 'cancel'. For timeouts, evException's value will be 'timeout'. If embedFormForControl is set to true, pass
    // 'submit' as a message over to the iframe to submit the form. On response, the parent will receive an object that
    // consists of the status, the token, and CardModel object. There are multiple ways to integrate the card store form.
    // You can use it within a popup, redirect, simple iframe, or iframe where the parent page has control to submit the
    // form. You can find example code for the advanced iframe integration on
    // [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).
        // Parameters:
            // showTimer - show or hide the timer.
            // showCard - show or hide the card visual.
            // walletSave - make true to store the card in your app's wallet. This overrides
            // the cardTtl and buttonText values. The CVV isn't requested if true.
            // If you intend to use the card in a transaction within 30 minutes,
            // set walletSave to false.
            // embedFormForControl - if true, it removes its buttons and
            // any additional padding/spacing, and enables the windows interface for 2-way comms.
            // TTL - form session time to live in seconds. After it expires, the form can no
            // longer be used.
            // xAPIVersion - the requested API version
            // cardTTL - the card's time to live in seconds (60-1800 secs).
            // Once expired the card is deleted from the vault. Use the /cardvault/cards/ttl
            // endpoint to extend it. This field is required if walletSave is false.
            // preserveFormat - if true, a Luhn passable token is returned consisting of the original first six and last
            // four.
            // cardTypes - card types, comma delimited. Omit for any card.
            // (amex, diners_club_carte_blanche, diners_club_international,
            // jcb, laser, visa_electron, visa, mastercard, discover, dankort, maestro, uatp, mir).
            // callbackURL - URL the user is redirected to after storing the card.
            // parentURL - the parent page URL. The store form uses it when embedFormForControl
            // is true to communicate with the parent window.
            // pageHeader - configurable page header.
            // language - the language to use on the form. Currently en (English), es (Spanish),
            // fr (French), and zh-Hans (Chinese simplified) are available.
            // submitButtonText - text of the submit button.
            // submitButtonColor - the hex color of the submit button.
            // cancelButtonColor - the hex color of the cancel button.
            // pageColor - the hex color of the page background.
            // submitButtonTextColor - the hex color of the submit button text.
            // cancelButtonTextColor - the hex color of the cancel button text.
            // pageTextColor - the hex color of the page text.
    func (client BaseClient) GetCardStoreFormMethod(ctx context.Context, showTimer bool, showCard bool, walletSave bool, embedFormForControl bool, TTL int32, xAPIVersion string, cardTTL *int32, preserveFormat *bool, cardTypes string, callbackURL string, parentURL string, pageHeader string, language string, submitButtonText string, submitButtonColor string, cancelButtonColor string, pageColor string, submitButtonTextColor string, cancelButtonTextColor string, pageTextColor string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetCardStoreFormMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: TTL,
             Constraints: []validation.Constraint{	{Target: "TTL", Name: validation.InclusiveMaximum, Rule: int64(1800), Chain: nil },
            	{Target: "TTL", Name: validation.InclusiveMinimum, Rule: int64(60), Chain: nil }}},
            { TargetValue: cardTTL,
             Constraints: []validation.Constraint{	{Target: "cardTTL", Name: validation.Null, Rule: false ,
            Chain: []validation.Constraint{	{Target: "cardTTL", Name: validation.InclusiveMaximum, Rule: int64(1800), Chain: nil },
            	{Target: "cardTTL", Name: validation.InclusiveMinimum, Rule: int64(60), Chain: nil },
            }}}},
            { TargetValue: pageHeader,
             Constraints: []validation.Constraint{	{Target: "pageHeader", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "pageHeader", Name: validation.MaxLength, Rule: 35, Chain: nil },
            	{Target: "pageHeader", Name: validation.MinLength, Rule: 3, Chain: nil },
            }}}},
            { TargetValue: language,
             Constraints: []validation.Constraint{	{Target: "language", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "language", Name: validation.Pattern, Rule: `^en|es|fr|zh-Hans$`, Chain: nil },
            }}}},
            { TargetValue: submitButtonText,
             Constraints: []validation.Constraint{	{Target: "submitButtonText", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "submitButtonText", Name: validation.MaxLength, Rule: 20, Chain: nil },
            	{Target: "submitButtonText", Name: validation.MinLength, Rule: 0, Chain: nil },
            }}}},
            { TargetValue: submitButtonColor,
             Constraints: []validation.Constraint{	{Target: "submitButtonColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "submitButtonColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: cancelButtonColor,
             Constraints: []validation.Constraint{	{Target: "cancelButtonColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "cancelButtonColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: pageColor,
             Constraints: []validation.Constraint{	{Target: "pageColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "pageColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: submitButtonTextColor,
             Constraints: []validation.Constraint{	{Target: "submitButtonTextColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "submitButtonTextColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: cancelButtonTextColor,
             Constraints: []validation.Constraint{	{Target: "cancelButtonTextColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "cancelButtonTextColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: pageTextColor,
             Constraints: []validation.Constraint{	{Target: "pageTextColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "pageTextColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetCardStoreFormMethod", err.Error())
            }

            req, err := client.GetCardStoreFormMethodPreparer(ctx, showTimer, showCard, walletSave, embedFormForControl, TTL, xAPIVersion, cardTTL, preserveFormat, cardTypes, callbackURL, parentURL, pageHeader, language, submitButtonText, submitButtonColor, cancelButtonColor, pageColor, submitButtonTextColor, cancelButtonTextColor, pageTextColor)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardStoreFormMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetCardStoreFormMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardStoreFormMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetCardStoreFormMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCardStoreFormMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetCardStoreFormMethodPreparer prepares the GetCardStoreFormMethod request.
        func (client BaseClient) GetCardStoreFormMethodPreparer(ctx context.Context, showTimer bool, showCard bool, walletSave bool, embedFormForControl bool, TTL int32, xAPIVersion string, cardTTL *int32, preserveFormat *bool, cardTypes string, callbackURL string, parentURL string, pageHeader string, language string, submitButtonText string, submitButtonColor string, cancelButtonColor string, pageColor string, submitButtonTextColor string, cancelButtonTextColor string, pageTextColor string) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        "embedFormForControl": autorest.Encode("query",embedFormForControl),
        "showCard": autorest.Encode("query",showCard),
        "showTimer": autorest.Encode("query",showTimer),
        "ttl": autorest.Encode("query",TTL),
        "walletSave": autorest.Encode("query",walletSave),
        }
            if cardTTL != nil {
            queryParameters["cardTtl"] = autorest.Encode("query",*cardTTL)
            }
            if preserveFormat != nil {
            queryParameters["preserveFormat"] = autorest.Encode("query",*preserveFormat)
            }
            if len(cardTypes) > 0 {
            queryParameters["cardTypes"] = autorest.Encode("query",cardTypes)
            }
            if len(callbackURL) > 0 {
            queryParameters["callbackUrl"] = autorest.Encode("query",callbackURL)
            }
            if len(parentURL) > 0 {
            queryParameters["parentUrl"] = autorest.Encode("query",parentURL)
            }
            if len(pageHeader) > 0 {
            queryParameters["pageHeader"] = autorest.Encode("query",pageHeader)
            }
            if len(language) > 0 {
            queryParameters["language"] = autorest.Encode("query",language)
                } else {
                queryParameters["language"] = autorest.Encode("query","en")
            }
            if len(submitButtonText) > 0 {
            queryParameters["submitButtonText"] = autorest.Encode("query",submitButtonText)
                } else {
                queryParameters["submitButtonText"] = autorest.Encode("query","Save")
            }
            if len(submitButtonColor) > 0 {
            queryParameters["submitButtonColor"] = autorest.Encode("query",submitButtonColor)
                } else {
                queryParameters["submitButtonColor"] = autorest.Encode("query","#0078e7")
            }
            if len(cancelButtonColor) > 0 {
            queryParameters["cancelButtonColor"] = autorest.Encode("query",cancelButtonColor)
                } else {
                queryParameters["cancelButtonColor"] = autorest.Encode("query","#f08080")
            }
            if len(pageColor) > 0 {
            queryParameters["pageColor"] = autorest.Encode("query",pageColor)
                } else {
                queryParameters["pageColor"] = autorest.Encode("query","#ffffff")
            }
            if len(submitButtonTextColor) > 0 {
            queryParameters["submitButtonTextColor"] = autorest.Encode("query",submitButtonTextColor)
                } else {
                queryParameters["submitButtonTextColor"] = autorest.Encode("query","#ffffff")
            }
            if len(cancelButtonTextColor) > 0 {
            queryParameters["cancelButtonTextColor"] = autorest.Encode("query",cancelButtonTextColor)
                } else {
                queryParameters["cancelButtonTextColor"] = autorest.Encode("query","#000000")
            }
            if len(pageTextColor) > 0 {
            queryParameters["pageTextColor"] = autorest.Encode("query",pageTextColor)
                } else {
                queryParameters["pageTextColor"] = autorest.Encode("query","#000000")
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/store/forms"),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetCardStoreFormMethodSender sends the GetCardStoreFormMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetCardStoreFormMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetCardStoreFormMethodResponder handles the response to the GetCardStoreFormMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetCardStoreFormMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetCulturesMethod sends the get cultures request.
        // Parameters:
            // xAPIVersion - the requested API version
            // cultureCode - ISO 639-1 (language) and ISO 3166-1 (country) code.
    func (client BaseClient) GetCulturesMethod(ctx context.Context, xAPIVersion string, cultureCode string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetCulturesMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
        req, err := client.GetCulturesMethodPreparer(ctx, xAPIVersion, cultureCode)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetCulturesMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetCulturesMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCulturesMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetCulturesMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCulturesMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetCulturesMethodPreparer prepares the GetCulturesMethod request.
        func (client BaseClient) GetCulturesMethodPreparer(ctx context.Context, xAPIVersion string, cultureCode string) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        }
            if len(cultureCode) > 0 {
            queryParameters["cultureCode"] = autorest.Encode("query",cultureCode)
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/references/cultures"),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetCulturesMethodSender sends the GetCulturesMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetCulturesMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetCulturesMethodResponder handles the response to the GetCulturesMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetCulturesMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetCvvStoreFormMethod the CVV store form allows your app to temporarily store the CVV until authorization. The CVV
    // ttl is set to the card's ttl. If the card has a ttl of -1, the CVV ttl will be set to 1800 seconds. If autoSave is
    // true, the callback will not trigger so the client app will need to verify the cvv ttl for its existence. There are
    // multiple ways to integrate the cvv form. You can use it within a popup, redirect, simple iframe, (previous 3 can use
    // autosave) or iframe where the parent page has control to submit the form. You can find example code for the advanced
    // iframe integration on [GitHub](https://github.com/Enigma-Vault/card-vault-integration-examples).
        // Parameters:
            // cardToken - card token.
            // showTimer - show or hide the timer.
            // showCancelButton - show or hide the cancel button.
            // autoSave - if true, the buttons and header are removed, and cvv will be autosaved after user entry.
            // The callback will not trigger so the client app will need to verify the cvv ttl for its existence.
            // embedFormForControl - if true, it removes its buttons and
            // any additional padding/spacing, and enables the windows interface for 2-way comms.
            // xAPIVersion - the requested API version
            // callbackURL - URL the user is redirected to after storing the card.
            // parentURL - the parent page URL. The store form uses it when embedFormForControl
            // is true to communicate with the parent window.
            // pageHeader - configurable page header.
            // language - the language to use on the form. Currently en (English), es (Spanish),
            // fr (French), and zh-Hans (Chinese simplified) are available.
            // submitButtonText - text of the submit button.
            // submitButtonColor - the hex color of the submit button.
            // cancelButtonColor - the hex color of the cancel button.
            // pageColor - the hex color of the page background.
            // submitButtonTextColor - the hex color of the submit button text.
            // cancelButtonTextColor - the hex color of the cancel button text.
            // pageTextColor - the hex color of the page text.
    func (client BaseClient) GetCvvStoreFormMethod(ctx context.Context, cardToken string, showTimer bool, showCancelButton bool, autoSave bool, embedFormForControl bool, xAPIVersion string, callbackURL string, parentURL string, pageHeader string, language string, submitButtonText string, submitButtonColor string, cancelButtonColor string, pageColor string, submitButtonTextColor string, cancelButtonTextColor string, pageTextColor string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetCvvStoreFormMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: cardToken,
             Constraints: []validation.Constraint{	{Target: "cardToken", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "cardToken", Name: validation.MinLength, Rule: 13, Chain: nil }}},
            { TargetValue: pageHeader,
             Constraints: []validation.Constraint{	{Target: "pageHeader", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "pageHeader", Name: validation.MaxLength, Rule: 35, Chain: nil },
            	{Target: "pageHeader", Name: validation.MinLength, Rule: 3, Chain: nil },
            }}}},
            { TargetValue: language,
             Constraints: []validation.Constraint{	{Target: "language", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "language", Name: validation.Pattern, Rule: `^en|es|fr|zh-Hans$`, Chain: nil },
            }}}},
            { TargetValue: submitButtonText,
             Constraints: []validation.Constraint{	{Target: "submitButtonText", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "submitButtonText", Name: validation.MaxLength, Rule: 20, Chain: nil },
            	{Target: "submitButtonText", Name: validation.MinLength, Rule: 0, Chain: nil },
            }}}},
            { TargetValue: submitButtonColor,
             Constraints: []validation.Constraint{	{Target: "submitButtonColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "submitButtonColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: cancelButtonColor,
             Constraints: []validation.Constraint{	{Target: "cancelButtonColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "cancelButtonColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: pageColor,
             Constraints: []validation.Constraint{	{Target: "pageColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "pageColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: submitButtonTextColor,
             Constraints: []validation.Constraint{	{Target: "submitButtonTextColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "submitButtonTextColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: cancelButtonTextColor,
             Constraints: []validation.Constraint{	{Target: "cancelButtonTextColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "cancelButtonTextColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}},
            { TargetValue: pageTextColor,
             Constraints: []validation.Constraint{	{Target: "pageTextColor", Name: validation.Empty, Rule: false ,
            Chain: []validation.Constraint{	{Target: "pageTextColor", Name: validation.Pattern, Rule: `^#(?:[0-9a-fA-F]{3}){1,2}$`, Chain: nil },
            }}}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetCvvStoreFormMethod", err.Error())
            }

            req, err := client.GetCvvStoreFormMethodPreparer(ctx, cardToken, showTimer, showCancelButton, autoSave, embedFormForControl, xAPIVersion, callbackURL, parentURL, pageHeader, language, submitButtonText, submitButtonColor, cancelButtonColor, pageColor, submitButtonTextColor, cancelButtonTextColor, pageTextColor)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetCvvStoreFormMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetCvvStoreFormMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCvvStoreFormMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetCvvStoreFormMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetCvvStoreFormMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetCvvStoreFormMethodPreparer prepares the GetCvvStoreFormMethod request.
        func (client BaseClient) GetCvvStoreFormMethodPreparer(ctx context.Context, cardToken string, showTimer bool, showCancelButton bool, autoSave bool, embedFormForControl bool, xAPIVersion string, callbackURL string, parentURL string, pageHeader string, language string, submitButtonText string, submitButtonColor string, cancelButtonColor string, pageColor string, submitButtonTextColor string, cancelButtonTextColor string, pageTextColor string) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        "autoSave": autorest.Encode("query",autoSave),
        "embedFormForControl": autorest.Encode("query",embedFormForControl),
        "showCancelButton": autorest.Encode("query",showCancelButton),
        "showTimer": autorest.Encode("query",showTimer),
        }
            if len(callbackURL) > 0 {
            queryParameters["callbackUrl"] = autorest.Encode("query",callbackURL)
            }
            if len(parentURL) > 0 {
            queryParameters["parentUrl"] = autorest.Encode("query",parentURL)
            }
            if len(pageHeader) > 0 {
            queryParameters["pageHeader"] = autorest.Encode("query",pageHeader)
            }
            if len(language) > 0 {
            queryParameters["language"] = autorest.Encode("query",language)
                } else {
                queryParameters["language"] = autorest.Encode("query","en")
            }
            if len(submitButtonText) > 0 {
            queryParameters["submitButtonText"] = autorest.Encode("query",submitButtonText)
                } else {
                queryParameters["submitButtonText"] = autorest.Encode("query","Submit")
            }
            if len(submitButtonColor) > 0 {
            queryParameters["submitButtonColor"] = autorest.Encode("query",submitButtonColor)
                } else {
                queryParameters["submitButtonColor"] = autorest.Encode("query","#0078e7")
            }
            if len(cancelButtonColor) > 0 {
            queryParameters["cancelButtonColor"] = autorest.Encode("query",cancelButtonColor)
                } else {
                queryParameters["cancelButtonColor"] = autorest.Encode("query","#f08080")
            }
            if len(pageColor) > 0 {
            queryParameters["pageColor"] = autorest.Encode("query",pageColor)
                } else {
                queryParameters["pageColor"] = autorest.Encode("query","#ffffff")
            }
            if len(submitButtonTextColor) > 0 {
            queryParameters["submitButtonTextColor"] = autorest.Encode("query",submitButtonTextColor)
                } else {
                queryParameters["submitButtonTextColor"] = autorest.Encode("query","#ffffff")
            }
            if len(cancelButtonTextColor) > 0 {
            queryParameters["cancelButtonTextColor"] = autorest.Encode("query",cancelButtonTextColor)
                } else {
                queryParameters["cancelButtonTextColor"] = autorest.Encode("query","#000000")
            }
            if len(pageTextColor) > 0 {
            queryParameters["pageTextColor"] = autorest.Encode("query",pageTextColor)
                } else {
                queryParameters["pageTextColor"] = autorest.Encode("query","#000000")
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/store/cvv/forms"),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("cardToken", autorest.String(cardToken)),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetCvvStoreFormMethodSender sends the GetCvvStoreFormMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetCvvStoreFormMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetCvvStoreFormMethodResponder handles the response to the GetCvvStoreFormMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetCvvStoreFormMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetDataEphemeralKeyMethod the ephemeralKey is a one time use expiring key that allows an external client to obtain
    // the token's secret. The destinationClientId is a valid Enigma Vault clientId of the destination app. The time to
    // live (ttl) is in seconds.
        // Parameters:
            // tokenParameter - reference to the vaulted secret.
            // destinationClientID - enigma Vault client granted use of the ephemeralKey.
            // TTL - time to live in seconds, max of 300.
            // xAPIVersion - the requested API version
    func (client BaseClient) GetDataEphemeralKeyMethod(ctx context.Context, tokenParameter string, destinationClientID string, TTL int32, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetDataEphemeralKeyMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: tokenParameter,
             Constraints: []validation.Constraint{	{Target: "tokenParameter", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "tokenParameter", Name: validation.MinLength, Rule: 72, Chain: nil }}},
            { TargetValue: TTL,
             Constraints: []validation.Constraint{	{Target: "TTL", Name: validation.InclusiveMaximum, Rule: int64(300), Chain: nil },
            	{Target: "TTL", Name: validation.InclusiveMinimum, Rule: int64(1), Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetDataEphemeralKeyMethod", err.Error())
            }

            req, err := client.GetDataEphemeralKeyMethodPreparer(ctx, tokenParameter, destinationClientID, TTL, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetDataEphemeralKeyMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetDataEphemeralKeyMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetDataEphemeralKeyMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetDataEphemeralKeyMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetDataEphemeralKeyMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetDataEphemeralKeyMethodPreparer prepares the GetDataEphemeralKeyMethod request.
        func (client BaseClient) GetDataEphemeralKeyMethodPreparer(ctx context.Context, tokenParameter string, destinationClientID string, TTL int32, xAPIVersion string) (*http.Request, error) {
            pathParameters := map[string]interface{} {
            "token": autorest.Encode("path",tokenParameter),
            }

            queryParameters := map[string]interface{} {
        "destinationClientId": autorest.Encode("query",destinationClientID),
        "ttl": autorest.Encode("query",TTL),
        }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPathParameters("/datavault/ephemeralkeys/{token}",pathParameters),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetDataEphemeralKeyMethodSender sends the GetDataEphemeralKeyMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetDataEphemeralKeyMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetDataEphemeralKeyMethodResponder handles the response to the GetDataEphemeralKeyMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetDataEphemeralKeyMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetDataSecretMethod the ephemeralKey is a one time use expiring key that allows an external client to obtain the
    // token's secret. To generate one, use the datavault/secrets/ephemeralKey endpoint.
        // Parameters:
            // tokenParameter - reference to the vaulted secret.
            // xAPIVersion - the requested API version
            // ephemeralKey - one time use expiring key.
    func (client BaseClient) GetDataSecretMethod(ctx context.Context, tokenParameter string, xAPIVersion string, ephemeralKey *uuid.UUID) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetDataSecretMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: tokenParameter,
             Constraints: []validation.Constraint{	{Target: "tokenParameter", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "tokenParameter", Name: validation.MinLength, Rule: 72, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetDataSecretMethod", err.Error())
            }

            req, err := client.GetDataSecretMethodPreparer(ctx, tokenParameter, xAPIVersion, ephemeralKey)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetDataSecretMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetDataSecretMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetDataSecretMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetDataSecretMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetDataSecretMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetDataSecretMethodPreparer prepares the GetDataSecretMethod request.
        func (client BaseClient) GetDataSecretMethodPreparer(ctx context.Context, tokenParameter string, xAPIVersion string, ephemeralKey *uuid.UUID) (*http.Request, error) {
            pathParameters := map[string]interface{} {
            "token": autorest.Encode("path",tokenParameter),
            }

            queryParameters := map[string]interface{} {
        }
            if ephemeralKey != nil {
            queryParameters["ephemeralKey"] = autorest.Encode("query",*ephemeralKey)
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPathParameters("/datavault/secrets/{token}",pathParameters),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetDataSecretMethodSender sends the GetDataSecretMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetDataSecretMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetDataSecretMethodResponder handles the response to the GetDataSecretMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetDataSecretMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetDownloadURLMethod the url is used to download the file out of the vault. The url has an exipration of five
    // minutes. When aSync is set to true for large files, a websocket API url is returned so that the file status can be
    // monitored in real time. When the file is finished decrypting, the download url is provided through the websocket
    // connection.
        // Parameters:
            // fileName - tokenized file name.
            // aSync - set to true to decrypt large files; you'll use the websocket API for notifications.
            // xAPIVersion - the requested API version
            // ephemeralKey - one time use expiring key.
    func (client BaseClient) GetDownloadURLMethod(ctx context.Context, fileName string, aSync bool, xAPIVersion string, ephemeralKey *uuid.UUID) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetDownloadURLMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: fileName,
             Constraints: []validation.Constraint{	{Target: "fileName", Name: validation.Pattern, Rule: `^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$`, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetDownloadURLMethod", err.Error())
            }

            req, err := client.GetDownloadURLMethodPreparer(ctx, fileName, aSync, xAPIVersion, ephemeralKey)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetDownloadURLMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetDownloadURLMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetDownloadURLMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetDownloadURLMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetDownloadURLMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetDownloadURLMethodPreparer prepares the GetDownloadURLMethod request.
        func (client BaseClient) GetDownloadURLMethodPreparer(ctx context.Context, fileName string, aSync bool, xAPIVersion string, ephemeralKey *uuid.UUID) (*http.Request, error) {
            pathParameters := map[string]interface{} {
            "fileName": autorest.Encode("path",fileName),
            }

            queryParameters := map[string]interface{} {
        "aSync": autorest.Encode("query",aSync),
        }
            if ephemeralKey != nil {
            queryParameters["ephemeralKey"] = autorest.Encode("query",*ephemeralKey)
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPathParameters("/filevault/downloadurls/{fileName}",pathParameters),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetDownloadURLMethodSender sends the GetDownloadURLMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetDownloadURLMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetDownloadURLMethodResponder handles the response to the GetDownloadURLMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetDownloadURLMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusAccepted,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusConflict,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetFileEphemeralKeyMethod the ephemeralKey is a one time use expiring key that allows an external client to obtain a
    // download url. The destinationClientId is a valid Enigma Vault clientId of the destination app. The time to live
    // (ttl) is in seconds.
        // Parameters:
            // fileName - tokenized file name.
            // destinationClientID - enigma Vault client granted use of the ephemeralKey.
            // TTL - time to live in seconds, max of 300.
            // xAPIVersion - the requested API version
    func (client BaseClient) GetFileEphemeralKeyMethod(ctx context.Context, fileName string, destinationClientID string, TTL int32, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetFileEphemeralKeyMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: fileName,
             Constraints: []validation.Constraint{	{Target: "fileName", Name: validation.Pattern, Rule: `^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$`, Chain: nil }}},
            { TargetValue: TTL,
             Constraints: []validation.Constraint{	{Target: "TTL", Name: validation.InclusiveMaximum, Rule: int64(300), Chain: nil },
            	{Target: "TTL", Name: validation.InclusiveMinimum, Rule: int64(1), Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetFileEphemeralKeyMethod", err.Error())
            }

            req, err := client.GetFileEphemeralKeyMethodPreparer(ctx, fileName, destinationClientID, TTL, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetFileEphemeralKeyMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetFileEphemeralKeyMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetFileEphemeralKeyMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetFileEphemeralKeyMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetFileEphemeralKeyMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetFileEphemeralKeyMethodPreparer prepares the GetFileEphemeralKeyMethod request.
        func (client BaseClient) GetFileEphemeralKeyMethodPreparer(ctx context.Context, fileName string, destinationClientID string, TTL int32, xAPIVersion string) (*http.Request, error) {
            pathParameters := map[string]interface{} {
            "fileName": autorest.Encode("path",fileName),
            }

            queryParameters := map[string]interface{} {
        "destinationClientId": autorest.Encode("query",destinationClientID),
        "ttl": autorest.Encode("query",TTL),
        }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPathParameters("/filevault/ephemeralkeys/{fileName}",pathParameters),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetFileEphemeralKeyMethodSender sends the GetFileEphemeralKeyMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetFileEphemeralKeyMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetFileEphemeralKeyMethodResponder handles the response to the GetFileEphemeralKeyMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetFileEphemeralKeyMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetFileStatusMethod this endpoint has been deprecated because the file status is now provided through a websocket
    // API.
        // Parameters:
            // fileName - tokenized file name.
            // xAPIVersion - the requested API version
    func (client BaseClient) GetFileStatusMethod(ctx context.Context, fileName string, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetFileStatusMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: fileName,
             Constraints: []validation.Constraint{	{Target: "fileName", Name: validation.Pattern, Rule: `^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\.[0-9a-zA-Z]{1,10}$`, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetFileStatusMethod", err.Error())
            }

            req, err := client.GetFileStatusMethodPreparer(ctx, fileName, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetFileStatusMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetFileStatusMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetFileStatusMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetFileStatusMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetFileStatusMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetFileStatusMethodPreparer prepares the GetFileStatusMethod request.
        func (client BaseClient) GetFileStatusMethodPreparer(ctx context.Context, fileName string, xAPIVersion string) (*http.Request, error) {
            pathParameters := map[string]interface{} {
            "fileName": autorest.Encode("path",fileName),
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPathParameters("/filevault/statuses/{fileName}",pathParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetFileStatusMethodSender sends the GetFileStatusMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetFileStatusMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetFileStatusMethodResponder handles the response to the GetFileStatusMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetFileStatusMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetTTLMethod the card's time to live in seconds. Once expired the card is deleted from the vault. If -1, the card
    // lives forever until manually deleted.
        // Parameters:
            // cardToken - card token.
            // xAPIVersion - the requested API version
            // ephemeralKey - expiring key for temporary access.
    func (client BaseClient) GetTTLMethod(ctx context.Context, cardToken string, xAPIVersion string, ephemeralKey *uuid.UUID) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetTTLMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: cardToken,
             Constraints: []validation.Constraint{	{Target: "cardToken", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "cardToken", Name: validation.MinLength, Rule: 13, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetTTLMethod", err.Error())
            }

            req, err := client.GetTTLMethodPreparer(ctx, cardToken, xAPIVersion, ephemeralKey)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetTTLMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetTTLMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetTTLMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetTTLMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetTTLMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetTTLMethodPreparer prepares the GetTTLMethod request.
        func (client BaseClient) GetTTLMethodPreparer(ctx context.Context, cardToken string, xAPIVersion string, ephemeralKey *uuid.UUID) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        }
            if ephemeralKey != nil {
            queryParameters["ephemeralKey"] = autorest.Encode("query",*ephemeralKey)
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/cards/ttl"),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("cardToken", autorest.String(cardToken)),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetTTLMethodSender sends the GetTTLMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetTTLMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetTTLMethodResponder handles the response to the GetTTLMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetTTLMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // GetUploadURLMethod the url is used to upload (PUT) a file into the vault. The url has an exipration of five minutes.
    // The file size cannot exceed 5 gigabytes. A websocket url is provided so that the status of the file can be tracked
    // in realtime.
        // Parameters:
            // contentType - the MIME type associated with the file.
            // fileExtension - the file extension without the leading .
            // xAPIVersion - the requested API version
    func (client BaseClient) GetUploadURLMethod(ctx context.Context, contentType string, fileExtension string, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.GetUploadURLMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: contentType,
             Constraints: []validation.Constraint{	{Target: "contentType", Name: validation.MaxLength, Rule: 255, Chain: nil },
            	{Target: "contentType", Name: validation.MinLength, Rule: 3, Chain: nil }}},
            { TargetValue: fileExtension,
             Constraints: []validation.Constraint{	{Target: "fileExtension", Name: validation.Pattern, Rule: `^[0-9a-zA-Z]{1,10}$`, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "GetUploadURLMethod", err.Error())
            }

            req, err := client.GetUploadURLMethodPreparer(ctx, contentType, fileExtension, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "GetUploadURLMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.GetUploadURLMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetUploadURLMethod", resp, "Failure sending request")
            return
            }

            result, err = client.GetUploadURLMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "GetUploadURLMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // GetUploadURLMethodPreparer prepares the GetUploadURLMethod request.
        func (client BaseClient) GetUploadURLMethodPreparer(ctx context.Context, contentType string, fileExtension string, xAPIVersion string) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        "contentType": autorest.Encode("query",contentType),
        "fileExtension": autorest.Encode("query",fileExtension),
        }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/filevault/uploadurls"),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // GetUploadURLMethodSender sends the GetUploadURLMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) GetUploadURLMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // GetUploadURLMethodResponder handles the response to the GetUploadURLMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) GetUploadURLMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // RetrieveCardMethod provides card data. The first six and the last four are included in the response. The ttl values
    // represent the time remaining in seconds until that item is purged. the original card information is not retreivable
    // by the client without the cardvault_raw scope (contact support). If you have the proper scope, use the
    // cardvault/raw/cards endpoint.
        // Parameters:
            // cardToken - card token.
            // xAPIVersion - the requested API version
            // ephemeralKey - expiring key for temporary access.
    func (client BaseClient) RetrieveCardMethod(ctx context.Context, cardToken string, xAPIVersion string, ephemeralKey *uuid.UUID) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.RetrieveCardMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: cardToken,
             Constraints: []validation.Constraint{	{Target: "cardToken", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "cardToken", Name: validation.MinLength, Rule: 13, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "RetrieveCardMethod", err.Error())
            }

            req, err := client.RetrieveCardMethodPreparer(ctx, cardToken, xAPIVersion, ephemeralKey)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "RetrieveCardMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.RetrieveCardMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "RetrieveCardMethod", resp, "Failure sending request")
            return
            }

            result, err = client.RetrieveCardMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "RetrieveCardMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // RetrieveCardMethodPreparer prepares the RetrieveCardMethod request.
        func (client BaseClient) RetrieveCardMethodPreparer(ctx context.Context, cardToken string, xAPIVersion string, ephemeralKey *uuid.UUID) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        }
            if ephemeralKey != nil {
            queryParameters["ephemeralKey"] = autorest.Encode("query",*ephemeralKey)
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/cards"),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("cardToken", autorest.String(cardToken)),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // RetrieveCardMethodSender sends the RetrieveCardMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) RetrieveCardMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // RetrieveCardMethodResponder handles the response to the RetrieveCardMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) RetrieveCardMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // RetrieveRawCardMethod special endpoint to retreive raw card data. It can only be used with the cardvault_raw scope.
        // Parameters:
            // cardToken - card token.
            // xAPIVersion - the requested API version
            // ephemeralKey - expiring key for temporary access.
    func (client BaseClient) RetrieveRawCardMethod(ctx context.Context, cardToken string, xAPIVersion string, ephemeralKey *uuid.UUID) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.RetrieveRawCardMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: cardToken,
             Constraints: []validation.Constraint{	{Target: "cardToken", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "cardToken", Name: validation.MinLength, Rule: 13, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "RetrieveRawCardMethod", err.Error())
            }

            req, err := client.RetrieveRawCardMethodPreparer(ctx, cardToken, xAPIVersion, ephemeralKey)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "RetrieveRawCardMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.RetrieveRawCardMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "RetrieveRawCardMethod", resp, "Failure sending request")
            return
            }

            result, err = client.RetrieveRawCardMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "RetrieveRawCardMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // RetrieveRawCardMethodPreparer prepares the RetrieveRawCardMethod request.
        func (client BaseClient) RetrieveRawCardMethodPreparer(ctx context.Context, cardToken string, xAPIVersion string, ephemeralKey *uuid.UUID) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        }
            if ephemeralKey != nil {
            queryParameters["ephemeralKey"] = autorest.Encode("query",*ephemeralKey)
            }

        preparer := autorest.CreatePreparer(
    autorest.AsGet(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/raw/cards"),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("cardToken", autorest.String(cardToken)),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // RetrieveRawCardMethodSender sends the RetrieveRawCardMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) RetrieveRawCardMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // RetrieveRawCardMethodResponder handles the response to the RetrieveRawCardMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) RetrieveRawCardMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // SearchDataSecretsMethod exact matches will only be returned and is case sensitive.
        // Parameters:
            // xAPIVersion - the requested API version
            // body - text to search within the vault. Exact matches will only be returned and is case sensitive.
    func (client BaseClient) SearchDataSecretsMethod(ctx context.Context, xAPIVersion string, body *PlaintextModelType) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.SearchDataSecretsMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: body,
             Constraints: []validation.Constraint{	{Target: "body", Name: validation.Null, Rule: false ,
            Chain: []validation.Constraint{	{Target: "body.Plaintext", Name: validation.Null, Rule: true, Chain: nil },
            }}}}}); err != nil {
            return result, validation.NewError(".BaseClient", "SearchDataSecretsMethod", err.Error())
            }

            req, err := client.SearchDataSecretsMethodPreparer(ctx, xAPIVersion, body)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "SearchDataSecretsMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.SearchDataSecretsMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "SearchDataSecretsMethod", resp, "Failure sending request")
            return
            }

            result, err = client.SearchDataSecretsMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "SearchDataSecretsMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // SearchDataSecretsMethodPreparer prepares the SearchDataSecretsMethod request.
        func (client BaseClient) SearchDataSecretsMethodPreparer(ctx context.Context, xAPIVersion string, body *PlaintextModelType) (*http.Request, error) {
        preparer := autorest.CreatePreparer(
    autorest.AsContentType("application/json; charset=utf-8"),
    autorest.AsPost(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/datavault/search"),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
            if body != nil {
            preparer = autorest.DecoratePreparer(preparer,
            autorest.WithJSON(body))
            }
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // SearchDataSecretsMethodSender sends the SearchDataSecretsMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) SearchDataSecretsMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // SearchDataSecretsMethodResponder handles the response to the SearchDataSecretsMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) SearchDataSecretsMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // StoreCardMethod when a card is stored in the vault, the original card information is not retrievable by the client
    // without the cardvault_raw scope (contact support). The CVV's ttl is set to the same ttl as the card unless the card
    // is stored permanently. If the card is stored permanently, the CVV's ttl is set to 30 minutes. The CVV is purged
    // after its first use or after its ttl expires, whichever comes first. After the card's ttl, the card is deleted. To
    // make the card permanent, leave out the ttl property. The full card number can be used through the proxy endpoint.
    // You can get the first six, the last four, full name, and expiration from /cardvault/cards (GET).
        // Parameters:
            // body - card information.
            // xAPIVersion - the requested API version
            // preserveFormat - if true, a Luhn passable token is returned consisting of the original first six and last
            // four.
    func (client BaseClient) StoreCardMethod(ctx context.Context, body CardModelType, xAPIVersion string, preserveFormat *bool) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.StoreCardMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: body,
             Constraints: []validation.Constraint{	{Target: "body.Ccn", Name: validation.Null, Rule: true, Chain: nil },
            	{Target: "body.FullName", Name: validation.Null, Rule: true, Chain: nil },
            	{Target: "body.ExpMonth", Name: validation.Null, Rule: true ,
            Chain: []validation.Constraint{	{Target: "body.ExpMonth", Name: validation.InclusiveMaximum, Rule: int64(12), Chain: nil },
            	{Target: "body.ExpMonth", Name: validation.InclusiveMinimum, Rule: int64(1), Chain: nil },
            }},
            	{Target: "body.ExpYear", Name: validation.Null, Rule: true, Chain: nil },
            	{Target: "body.CardType", Name: validation.Null, Rule: true, Chain: nil },
            	{Target: "body.CvvTTL", Name: validation.Null, Rule: true ,
            Chain: []validation.Constraint{	{Target: "body.CvvTTL", Name: validation.InclusiveMaximum, Rule: int64(1800), Chain: nil },
            	{Target: "body.CvvTTL", Name: validation.InclusiveMinimum, Rule: int64(0), Chain: nil },
            }},
            	{Target: "body.TTL", Name: validation.Null, Rule: false ,
            Chain: []validation.Constraint{	{Target: "body.TTL", Name: validation.InclusiveMaximum, Rule: int64(1800), Chain: nil },
            	{Target: "body.TTL", Name: validation.InclusiveMinimum, Rule: int64(60), Chain: nil },
            }}}}}); err != nil {
            return result, validation.NewError(".BaseClient", "StoreCardMethod", err.Error())
            }

            req, err := client.StoreCardMethodPreparer(ctx, body, xAPIVersion, preserveFormat)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "StoreCardMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.StoreCardMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "StoreCardMethod", resp, "Failure sending request")
            return
            }

            result, err = client.StoreCardMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "StoreCardMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // StoreCardMethodPreparer prepares the StoreCardMethod request.
        func (client BaseClient) StoreCardMethodPreparer(ctx context.Context, body CardModelType, xAPIVersion string, preserveFormat *bool) (*http.Request, error) {
        queryParameters := map[string]interface{} {
        }
            if preserveFormat != nil {
            queryParameters["preserveFormat"] = autorest.Encode("query",*preserveFormat)
            }

        preparer := autorest.CreatePreparer(
    autorest.AsContentType("application/json; charset=utf-8"),
    autorest.AsPost(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/cards"),
    autorest.WithJSON(body),
    autorest.WithQueryParameters(queryParameters),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // StoreCardMethodSender sends the StoreCardMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) StoreCardMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // StoreCardMethodResponder handles the response to the StoreCardMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) StoreCardMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // StoreDataSecretsMethod supports up to 5,000 plaintext objects per request. Plaintext strings must be less than 1000
    // characters in length. The customIdentifier attribute ties your unencrypted data to the tokens. The customIdentifier
    // is not stored within the vault.
        // Parameters:
            // body - your secrets to vault.
            // xAPIVersion - the requested API version
    func (client BaseClient) StoreDataSecretsMethod(ctx context.Context, body []PlaintextCustomerIdentifierModelType, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.StoreDataSecretsMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: body,
             Constraints: []validation.Constraint{	{Target: "body", Name: validation.Null, Rule: true, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "StoreDataSecretsMethod", err.Error())
            }

            req, err := client.StoreDataSecretsMethodPreparer(ctx, body, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "StoreDataSecretsMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.StoreDataSecretsMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "StoreDataSecretsMethod", resp, "Failure sending request")
            return
            }

            result, err = client.StoreDataSecretsMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "StoreDataSecretsMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // StoreDataSecretsMethodPreparer prepares the StoreDataSecretsMethod request.
        func (client BaseClient) StoreDataSecretsMethodPreparer(ctx context.Context, body []PlaintextCustomerIdentifierModelType, xAPIVersion string) (*http.Request, error) {
        preparer := autorest.CreatePreparer(
    autorest.AsContentType("application/json; charset=utf-8"),
    autorest.AsPost(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/datavault/secrets"),
    autorest.WithJSON(body),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // StoreDataSecretsMethodSender sends the StoreDataSecretsMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) StoreDataSecretsMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // StoreDataSecretsMethodResponder handles the response to the StoreDataSecretsMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) StoreDataSecretsMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

    // UpdateCardTTLMethod adjusts the time (seconds) until deletion. Additional time cannot be added to the CVV's ttl.
        // Parameters:
            // body - new card ttl value.
            // cardToken - card token.
            // xAPIVersion - the requested API version
    func (client BaseClient) UpdateCardTTLMethod(ctx context.Context, body CardTTLModelType, cardToken string, xAPIVersion string) (result SetObjectType, err error) {
        if tracing.IsEnabled() {
            ctx = tracing.StartSpan(ctx, fqdn + "/BaseClient.UpdateCardTTLMethod")
            defer func() {
                sc := -1
            if result.Response.Response != nil {
            sc = result.Response.Response.StatusCode
            }
                tracing.EndSpan(ctx, sc, err)
            }()
        }
            if err := validation.Validate([]validation.Validation{
            { TargetValue: body,
             Constraints: []validation.Constraint{	{Target: "body.TTL", Name: validation.Null, Rule: true ,
            Chain: []validation.Constraint{	{Target: "body.TTL", Name: validation.InclusiveMaximum, Rule: int64(1800), Chain: nil },
            	{Target: "body.TTL", Name: validation.InclusiveMinimum, Rule: int64(60), Chain: nil },
            }}}},
            { TargetValue: cardToken,
             Constraints: []validation.Constraint{	{Target: "cardToken", Name: validation.MaxLength, Rule: 72, Chain: nil },
            	{Target: "cardToken", Name: validation.MinLength, Rule: 13, Chain: nil }}}}); err != nil {
            return result, validation.NewError(".BaseClient", "UpdateCardTTLMethod", err.Error())
            }

            req, err := client.UpdateCardTTLMethodPreparer(ctx, body, cardToken, xAPIVersion)
        if err != nil {
        err = autorest.NewErrorWithError(err, ".BaseClient", "UpdateCardTTLMethod", nil , "Failure preparing request")
        return
        }

            resp, err := client.UpdateCardTTLMethodSender(req)
            if err != nil {
            result.Response = autorest.Response{Response: resp}
            err = autorest.NewErrorWithError(err, ".BaseClient", "UpdateCardTTLMethod", resp, "Failure sending request")
            return
            }

            result, err = client.UpdateCardTTLMethodResponder(resp)
            if err != nil {
            err = autorest.NewErrorWithError(err, ".BaseClient", "UpdateCardTTLMethod", resp, "Failure responding to request")
            return
            }

        return
    }

        // UpdateCardTTLMethodPreparer prepares the UpdateCardTTLMethod request.
        func (client BaseClient) UpdateCardTTLMethodPreparer(ctx context.Context, body CardTTLModelType, cardToken string, xAPIVersion string) (*http.Request, error) {
        preparer := autorest.CreatePreparer(
    autorest.AsContentType("application/json; charset=utf-8"),
    autorest.AsPut(),
    autorest.WithBaseURL(client.BaseURI),
    autorest.WithPath("/cardvault/cards/ttl"),
    autorest.WithJSON(body),
    autorest.WithHeader("cardToken", autorest.String(cardToken)),
    autorest.WithHeader("x-api-version", autorest.String(xAPIVersion)))
        return preparer.Prepare((&http.Request{}).WithContext(ctx))
        }

        // UpdateCardTTLMethodSender sends the UpdateCardTTLMethod request. The method will close the
        // http.Response Body if it receives an error.
        func (client BaseClient) UpdateCardTTLMethodSender(req *http.Request) (*http.Response, error) {
                    return client.Send(req, autorest.DoRetryForStatusCodes(client.RetryAttempts, client.RetryDuration, autorest.StatusCodesForRetry...))
                    }

        // UpdateCardTTLMethodResponder handles the response to the UpdateCardTTLMethod request. The method always
        // closes the http.Response Body.
        func (client BaseClient) UpdateCardTTLMethodResponder(resp *http.Response) (result SetObjectType, err error) {
                err = autorest.Respond(
                resp,
                azure.WithErrorUnlessStatusCode(http.StatusOK,http.StatusNoContent,http.StatusBadRequest,http.StatusUnauthorized,http.StatusForbidden,http.StatusNotFound,http.StatusRequestEntityTooLarge,http.StatusUnsupportedMediaType,http.StatusInternalServerError),
                autorest.ByUnmarshallingJSON(&result.Value),
                autorest.ByClosing())
                result.Response = autorest.Response{Response: resp}
                return
        }

